@@ -14,7 +14,7 @@
 # pip install {opts} {packages}
 
 ZUUL_CLONER=/usr/zuul-env/bin/zuul-cloner
-BRANCH_NAME=master
+BRANCH_NAME=stable/queens
 neutron_installed=$(echo "import neutron" | python 2>/dev/null ; echo $?)
 NEUTRON_DIR=$HOME/neutron
 
@@ -24,6 +24,8 @@ set -x
 install_cmd="pip install -c$1"
 shift
 
+PARAMS="$*"
+
 # The devstack based functional tests have neutron checked out in
 # $NEUTRON_DIR on the test systems - with the change to test in it.
 # Use this directory if it exists, so that this script installs the
@@ -66,5 +68,8 @@ else
     $install_cmd -U -e $SRC_DIR
 fi
 
-$install_cmd -U $*
+if [ -n "${PARAMS}" ]; then
+   $install_cmd -U ${PARAMS}
+fi
+
 exit $?
